@@ -135,7 +135,7 @@ def get_assembly_metadata_by_bioproject_accessions(bioproject_accessions: List[s
 
 
 def iterate_reply(genome_api_func, func_arg, **kwargs):
-    page_token = None
+    page_token = ""
     try:
         while True:
             assembly_reply = genome_api_func(func_arg, page_size=PAGE_SIZE_MAX, page_token=page_token, **kwargs)
